==> index_now-1.0.2.tar.gz: index_now/src/TermOperations.php <==
<?php

namespace Drupal\index_now;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Url;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\user\RoleInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Node operations class.
 */
class TermOperations implements ContainerInjectionInterface, TermOperationsInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The index now service.
   *
   * @var \Drupal\index_now\Service\IndexNowInterface
   */
  protected $indexNow;

  /**
   * The role storage.
   *
   * @var \Drupal\user\RoleStorage
   */
  protected $roleStorage;

  /**
   * Node operations class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\index_now\Service\IndexNowInterface $index_now
   *   The index now service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    IndexNowInterface $index_now
  ) {
    $this->configFactory = $config_factory;
    $this->roleStorage = $entity_type_manager->getStorage('user_role');
    $this->indexNow = $index_now;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('index_now.indexnow')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function pingIndexNow(Term $term) {
    $filename = DRUPAL_ROOT . "/index_now_key.txt";
    if (file_exists($filename) && $this->isIndexable($term)) {
      $term_url = Url::fromRoute('entity.taxonomy_term.canonical', ['taxonomy_term' => $term->id()], ['absolute' => TRUE]);
      $this->indexNow->sendRequest($term_url->toString());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function isIndexable(Term $term) {
    if (!$term->isPublished()) {
      return FALSE;
    }

    /** @var \Drupal\user\Entity\Role $anonymous_role */
    $anonymous_role = $this->roleStorage->load(RoleInterface::ANONYMOUS_ID);
    if (!$anonymous_role->hasPermission('access content')) {
      return FALSE;
    }

    $exclude_vocabularies = $this->configFactory
      ->getEditable('index_now.settings')
      ->get('exclude_voabularies');
    $exclude_vocabularies = !is_array($exclude_vocabularies) ? [] : array_filter(array_values($exclude_vocabularies));

    return !in_array($term->bundle(), $exclude_vocabularies);
  }

}

==> index_now-1.0.8.tar.gz: index_now/src/TermOperations.php <==
<?php

namespace Drupal\index_now;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Url;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\user\RoleInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Node operations class.
 */
class TermOperations implements ContainerInjectionInterface, TermOperationsInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The index now service.
   *
   * @var \Drupal\index_now\Service\IndexNowInterface
   */
  protected $indexNow;

  /**
   * The role storage.
   *
   * @var \Drupal\user\RoleStorage
   */
  protected $roleStorage;

  /**
   * Node operations class constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\index_now\Service\IndexNowInterface $index_now
   *   The index now service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    IndexNowInterface $index_now
  ) {
    $this->configFactory = $config_factory;
    $this->roleStorage = $entity_type_manager->getStorage('user_role');
    $this->indexNow = $index_now;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('index_now.indexnow')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function pingIndexNow(Term $term) {
    if ($this->isIndexable($term)) {
      $options = [
        'absolute' => TRUE,
        'language' => $term->language(),
      ];
      $term_url = Url::fromRoute('entity.taxonomy_term.canonical', ['taxonomy_term' => $term->id()], $options);
      $this->indexNow->sendRequest($term_url->toString());
    }
  }

  /**
   * {@inheritdoc}
   */
  public function isIndexable(Term $term) {
    if (!$term->isPublished()) {
      return FALSE;
    }

    /** @var \Drupal\user\Entity\Role $anonymous_role */
    $anonymous_role = $this->roleStorage->load(RoleInterface::ANONYMOUS_ID);
    if (!$anonymous_role->hasPermission('access content')) {
      return FALSE;
    }

    $exclude_vocabularies = $this->configFactory
      ->getEditable('index_now.settings')
      ->get('exclude_vocabularies');
    $exclude_vocabularies = !is_array($exclude_vocabularies) ? [] : array_filter(array_values($exclude_vocabularies));

    return !in_array($term->bundle(), $exclude_vocabularies);
  }

}
